ClassicHeader class

The most common refresh header, combining text and an icon.

See also:

ClassicFooter, the footer version of this indicator.

Inheritance

Constructors

ClassicHeader({Key? key, RefreshStyle refreshStyle = RefreshStyle.Follow, double height = 60.0, Duration completeDuration = const Duration(milliseconds: 600), OuterBuilder? outerBuilder, TextStyle? textStyle, Color? color, Color? arrowColor, Color? iconColor, String? releaseText, String? refreshingText, Widget? canTwoLevelIcon, Widget? twoLevelView, String? canTwoLevelText, String? completeText, String? failedText, String? idleText, IconPosition iconPos = IconPosition.left, double spacing = 15.0, Widget? refreshingIcon, Widget? failedIcon, Widget? completeIcon, Widget? idleIcon, Widget? releaseIcon, String? semanticsLabel, String? semanticsHint})
Creates a ClassicHeader.
const

Properties

arrowColor Color?
The color used by the default directional arrow icons.
final
canTwoLevelIcon Widget?
Custom icons for different refresh states.
final
canTwoLevelText String?
Custom text for different refresh states.
final
color Color?
The primary color used by the default spinner and text.
final
completeDuration Duration
The duration the indicator remains visible after the refresh is complete or fails.
finalinherited
completeIcon Widget?
Custom icons for different refresh states.
final
completeText String?
Custom text for different refresh states.
final
failedIcon Widget?
Custom icons for different refresh states.
final
failedText String?
Custom text for different refresh states.
final
hashCode int
The hash code for this object.
no setterinherited
height double
The height of the indicator's visual extent.
finalinherited
iconColor Color?
The color used by the default completion and failure icons.
final
iconPos IconPosition
The position of the icon relative to the text.
final
idleIcon Widget?
Custom icons for different refresh states.
final
idleText String?
Custom text for different refresh states.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset double
The layout offset of the indicator.
finalinherited
outerBuilder OuterBuilder?
A builder for re-wrapping the child. Use this to change background, padding, etc.
final
refreshingIcon Widget?
Custom icons for different refresh states.
final
refreshingText String?
Custom text for different refresh states.
final
refreshStyle RefreshStyle?
The display style of the refresh header.
finalinherited
releaseIcon Widget?
Custom icons for different refresh states.
final
releaseText String?
Custom text for different refresh states.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsHint String?
Custom accessibility hint for the indicator.
final
semanticsLabel String?
Custom accessibility label for the indicator.
final
spacing double
The margin between the icon and the text.
final
textStyle TextStyle?
The style of the text in the indicator.
final
twoLevelView Widget?
Custom icons for different refresh states.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited