LoadStatus enum

The current status of the loading footer.

Inheritance
Available extensions

Values

idle → const LoadStatus

Initial state, which can trigger loading more by a pull-up gesture.

canLoading → const LoadStatus

Dragged far enough that the onLoading callback will be triggered.

loading → const LoadStatus

The indicator is currently loading more data.

noMore → const LoadStatus

The indicator has no more data to load; this state prevents further loading.

failed → const LoadStatus

The indicator load has failed. It can be clicked to retry. If you want pull-up to trigger retry, set enableLoadingWhenFailed to true.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LoadStatus>
A constant List of the values in this enum, in order of their declaration.