RefreshNotifier<T> class
A value notifier that manages refresh states.
- Inheritance
-
- Object
- ChangeNotifier
- RefreshNotifier
- Implemented types
Constructors
- RefreshNotifier(T _value)
- Creates a RefreshNotifier with an initial value.
Properties
- error ↔ Object?
-
The error that occurred during the refresh/load process.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace ↔ StackTrace?
-
The stack trace associated with the error.
getter/setter pair
- value ↔ T
-
The current value of the notifier.
getter/setter pairoverride-getter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setError(
Object? err, StackTrace? st) → void - Sets the error and stack trace and notifies listeners.
-
setValueWithNoNotify(
T newValue) → void - Sets the value without notifying listeners.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited